<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 11/16/2003 *
 * ===============                              Last change: 12/13/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : mysql-connect.php                                *
 * -------------------------------------------------------------------- *
 * Short description : Connects to your database                        *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Verbindet zu Ihrer Datenbank                     *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4) . "/security.php";
	require($INC);
}

// CFG: DEBUG-SQL (if enabled and DEBUG_MODE is enabled all SQL queries will be logged to debug.log)
define('DEBUG_SQL', false);

// Non-database functions
require("inc/functions.php");

// Load more function libraries or includes
foreach (array('request-functions', 'session-functions', 'config-functions', 'filters', 'mysql-manager', 'extensions', 'db/lib', 'handler', 'hooks', 'session') as $lib) {
	// Load special functions
	LOAD_INC_ONCE(sprintf("inc/%s.php", $lib));
} // END - foreach

// Set error handler
set_error_handler('__errorHandler');

// Register shutdown hook
register_shutdown_function('__SHUTDOWN_HOOK');

// Check if the user setups his MySQL stuff...
if ((empty($MySQL['login'])) && (!defined('mxchange_installing')) && (!REQUEST_ISSET_GET(('installing'))) && (isBooleanConstantAndTrue('mxchange_installed'))) {
	// No login entered and outside installation mode
	OUTPUT_HTML("<strong>{--LANG_WARNING--}:</strong> ");
	if (isBooleanConstantAndTrue('mxchange_installed')) {
		// You have changed my configuration file!
		mxchange_die("{--DIE_CONFIG_CHANGED_YOU--}");
	} else {
		// Please run the installation script (maybe again)
		mxchange_die("{--DIE_RUN_INSTALL_MYSQL--}");
	}
} elseif ((!isBooleanConstantAndTrue('mxchange_installing')) && (!REQUEST_ISSET_GET(('installing'))) && (empty($MySQL['password'])) && (isBooleanConstantAndTrue('warn_no_pass'))) {
	// No database password entered!!!
	OUTPUT_HTML("<div>{--LANG_WARNING--}:</div> {--WARN_NULL_PASSWORD--}");
}

// Set dummy $_CONFIG array
$_CONFIG = array(
	'code_length' => 0,
	'patch_level' => 0,
	'last_update' => time()
);

// Set important header_sent
$GLOBALS['header_sent'] = 0;

// Init fatal messages
initFatalMessages();

// Check if this file is writeable or read-only and warn the user
if ((!isBooleanConstantAndTrue('mxchange_installing')) && (isBooleanConstantAndTrue('mxchange_installed'))) {
	// Check for write-permission for config.php and inc directory
	if (empty($GLOBALS['module'])) $GLOBALS['module'] = "index";

	// CSS array
	EXT_INIT_CSS_FILES();

	if ((!empty($MySQL['host'])) && (!empty($MySQL['login'])) && (!empty($MySQL['password'])) && (!empty($MySQL['dbase']))) {
		// Connect to DB
		SQL_CONNECT($MySQL['host'], $MySQL['login'], $MySQL['password'], __FILE__, __LINE__);

		// Is the link valid?
		if (SQL_IS_LINK_UP()) {
			// Is it a valid resource?
			if (SQL_SELECT_DB($MySQL['dbase'], __FILE__, __LINE__) === true) {
				// This is required for extension 'optimize' to work
				define('__DB_NAME', $MySQL['dbase']);

				// Remove MySQL array from namespace
				unset($MySQL);

				// Load configuration stuff
				mergeConfig(LOAD_CONFIG());

				// Load "databases" aka static arrays
				LOAD_INC_ONCE("inc/databases.php");

				// Loading patching system is required here...
				LOAD_INC_ONCE("inc/patch-system.php"); // Initialize patch system

				// Run daily reset
				LOAD_INC_ONCE("inc/check-reset.php");

				// Load admin include file if he is admin
				if (IS_ADMIN()) {
					// Administrative functions
					LOAD_INC_ONCE("inc/modules/admin/admin-inc.php");
				} // END - if
				//* DEBUG: */ ADD_POINTS_REFSYSTEM("test", 36, 1000);
				//* DEBUG: */ die();

				// Get all values
				if (($GLOBALS['output_mode'] != 1) && ($GLOBALS['output_mode'] != -1)) {
					if (empty($GLOBALS['module']))  $GLOBALS['module'] = "empty";
					if (empty($GLOBALS['what']))    $GLOBALS['what']   = GET_WHAT($GLOBALS['module']);
					if (empty($GLOBALS['action']))  $GLOBALS['action'] = GET_ACTION($GLOBALS['module'], $GLOBALS['what']);
				} else {
					// Set action/what to empty
					$GLOBALS['action'] = "";
					$GLOBALS['what']   = "";
				}

				// Run the init filter chain
				RUN_FILTER('init');

				// Set default 'what' value
				//* DEBUG: */ OUTPUT_HTML("-".$GLOBALS['module']."/".$GLOBALS['what']."-<br />");
				if ((empty($GLOBALS['what'])) && (empty($GLOBALS['action'])) && ($GLOBALS['output_mode'] != 1) && ($GLOBALS['output_mode'] != -1)) {
					if ($GLOBALS['module'] == "admin") {
						// Set 'action' value to 'login' in admin menu
						$GLOBALS['action'] = GET_ACTION($GLOBALS['module'], $GLOBALS['what']);
					} elseif (($GLOBALS['module'] == "index") || ($GLOBALS['module'] == "login")) {
						// Set 'what' value to 'welcome' in guest and member menu
						$GLOBALS['what'] = "welcome";
						if (getConfig('index_home') != "") $GLOBALS['what'] = getConfig('index_home');
					} else {
						// Anything else like begging link
						$GLOBALS['what'] = "";
					}
				} // END - if

				// Update sending pool
				if (($GLOBALS['output_mode'] != "1") && ($GLOBALS['output_mode'] != "-1")) LOAD_INC_ONCE("inc/pool-update.php"); // Sends out mails in configureable steps

				// Load all active extension including language files when not upgrading.
				// Check module for testing and count one click
				$dummy = CHECK_MODULE($GLOBALS['module']);
				if ($dummy == "done") COUNT_MODULE($GLOBALS['module']);
				unset($dummy);

				// Shall we activate the exchange?
				if (getConfig('activate_xchange') > 0) activateExchange();

				// Is the extension sql_patches installed and at least 0.3.6?
				if (GET_EXT_VERSION("sql_patches") >= "0.3.6") {
					// Generate random number
					if (isset($GLOBALS['userid'])) {
						define('RAND_NUMBER', GEN_RANDOM_CODE(10, mt_rand(10000,32766), $GLOBALS['userid'], ""));
					} else {
						define('RAND_NUMBER', GEN_RANDOM_CODE(10, mt_rand(10000,32766), 0, ""));
					}
				} else {
					// Generate weak (!!!) code
					define('RAND_NUMBER', mt_rand(1000000, 9999999));
				}
			} else {
				// Add language system
				LOAD_INC_ONCE("inc/language.php");

				// Wrong database?
				addFatalMessage(getMessage('WRONG_DB_SELECTED'));
			}
		} else {
			// Add language system
			LOAD_INC_ONCE("inc/language.php");

			// No link to database!
			addFatalMessage(getMessage('NO_DB_LINK'));
		}
	} else {
		// Add language system
		LOAD_INC_ONCE("inc/language.php");

		// Maybe you forgot to enter your MySQL data?
		addFatalMessage(getMessage('MYSQL_DATA_MISSING'));
	}
} else {
	///////////////////////////////////////////////////
	// Include neccessary functions for installation //
	///////////////////////////////////////////////////

	// Set other missing variables
	if (!isset($GLOBALS['output_mode'])) $GLOBALS['output_mode'] = "0";

	// Include databases.php
	LOAD_INC_ONCE("inc/databases.php");

	// Check if we are in installation routine
	if ((basename($_SERVER['PHP_SELF']) != "install.php") && ($GLOBALS['output_mode'] != "1") && ($GLOBALS['output_mode'] != -1)) {
		// Redirect to the installation system
		LOAD_URL("install.php");
	} // END - if

	// Double-check installation mode
	if ((!isBooleanConstantAndTrue('mxchange_installed')) || (!isBooleanConstantAndTrue('admin_registered'))) {
		// Check for file permissions
		if (!IS_INC_WRITEABLE("config")) {
			addFatalMessage(getMessage('CONFIG_IS_WRITE_PROTECTED'));
		} // END - if
		if (!IS_INC_WRITEABLE("dummy")) {
			addFatalMessage(getMessage('DUMMY_IS_WRITE_PROTECTED'));
		} // END - if
		if (!IS_INC_WRITEABLE(".secret/dummy")) {
			addFatalMessage(getMessage('SECRET_IS_WRITE_PROTECTED'));
		} // END - if
	} // END - if
}

if ((getTotalFatalErrors() > 0) && (isBooleanConstantAndTrue('mxchange_installed')) && (!defined('mxchange_installing')) && ($GLOBALS['output_mode'] != "1")) {
	// One or more fatal error(s) occur during connect...
	LOAD_INC_ONCE("inc/header.php");
	LOAD_INC_ONCE("inc/fatal_errors.php");
	LOAD_INC_ONCE("inc/footer.php");
} // END - if

//
?>
